package jboss.example.ejb;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import javax.annotation.Resource;
import javax.ejb.Local;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;

// Security related imports
import javax.annotation.security.RolesAllowed;
import javax.annotation.security.PermitAll;
import org.jboss.ejb3.annotation.SecurityDomain;
import java.security.Principal;

// EAP 6
import org.jboss.ws.api.annotation.WebContext;
import javax.jws.*;


@WebContext( contextRoot="/hello", 
             urlPattern="/bean", 
             authMethod="BASIC",
             secureWSDLAccess= false)
@WebService
@SecurityDomain("jmx-console")
@RolesAllowed({})
@Stateless(name="Hello")
@Remote(Hello.class)
@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
public class HelloBean implements Hello
{
    @Resource
    private SessionContext context;

    @RolesAllowed("JBossAdmin")
    @WebMethod
    public String sayHello()
    {
       System.out.println("session context: "+context);
       Principal principal = context.getCallerPrincipal();
       System.out.println("Principal: "+principal);
       System.out.println("caller name: "+context.getCallerPrincipal().getName());

       if( context.isCallerInRole("JBossAdmin") ) {
         System.out.println("User is in role!!");
       }

       String name = getName();
       return "Hello " + name + "!";
    }

   private String getName()
   {
      Properties props = new Properties();
      try
      {
         InputStream propertiesFile = HelloBean.class.getResourceAsStream("names.properties");
         props.load(propertiesFile);
      }
      catch (IOException ex)
      {
         return "Unable to get properties: " + ex.getMessage();
      }
      return (String) props.get("key");
   }
}
